<?php

/**
 * comments.php
 */

// Kill if being directly accessed
if ( !empty( $_SERVER[ 'SCRIPT_FILENAME' ] ) && 'comments.php' == basename( $_SERVER[ 'SCRIPT_FILENAME' ] ) ) {
  die( 'Please do not load this page directly. Thanks!' );
}

// If password requested
if ( post_password_required() ) {
  
?>

<p class="no-comments"><?php _e( 'This post is password protected. Enter the password to view comments.', 'poetic' ); ?></p>

<?php return; } ?>

<?php if ( have_comments() ) : ?>
  <div id="comments">

    <h2 class="comments-title">
      <?php
        $comments_number = get_comments_number();
        if ( 1 === $comments_number ) {
          /* translators: %s: post title */
          printf( _x( 'One thought on &ldquo;%s&rdquo;', 'comments title', 'poetic' ), get_the_title() );
        } else {
          printf(
            /* translators: 1: number of comments, 2: post title */
            _nx(
              '%1$s thought on &ldquo;%2$s&rdquo;',
              '%1$s thoughts on &ldquo;%2$s&rdquo;',
              $comments_number,
              'comments title',
              'poetic'
            ),
            number_format_i18n( $comments_number ),
            get_the_title()
          );
        }
      ?>
    </h2>

    <?php the_comments_navigation(); ?>

    <ol class="commentlist">
      <?php
        $gravatar = get_option( 'theme_gravatar' );
        $size     = get_option( 'theme_gravatar_size' );
        if ( $gravatar == true ) {
          wp_list_comments( 'avatar_size=' . $size . '&type=comment&callback=custom_comments_template' );
        } else {
          wp_list_comments( 'type=comment&callback=custom_comments_template' );
        }
      ?>
    </ol>

    <?php the_comments_navigation(); ?>

  </div>
<?php endif; ?>

<?php
  // If comments are closed and there are comments, let's leave a little note, shall we?
  if ( ! comments_open() && get_comments_number() && post_type_supports( get_post_type(), 'comments' ) ) :
?>
  <p class="no-comments"><?php _e( 'Comments are closed.', 'poetic' ); ?></p>
<?php endif; ?>


<?php

  $commenter = wp_get_current_commenter();
  $req = get_option( 'require_name_email' );
  $aria_req = ( $req ? " aria-required='true'" : '' );

  $fields = array(

    'author' => 
      '<div class="form-group fc-container">
        <label for="author" class="sr-only">' . __( 'Name', 'poetic' ) . $aria_req . '</label>
        <input type="text" class="form-field" name="author" id="author" value="' . $comment_author . '" placeholder="' . __( 'Name', 'poetic' ) . '">
      </div>',

    'email' => 
      '<div class="form-group fc-container">
        <label for="email" class="sr-only">' . __( 'Email', 'poetic' ) . $aria_req . '</label>
        <input type="text" class="form-field" name="email" id="email" value="' . $comment_author_email . '" placeholder="' . __( 'Email', 'poetic' ) . '">
      </div>',

    'email' => 
      '<div class="form-group fc-container">
        <label for="url" class="sr-only">' . __( 'Website', 'poetic' ) . '</label>
        <input type="text" class="form-field" name="url" id="url" value="' . $comment_author_email . '" placeholder="' . __( 'Website', 'poetic' ) . '">
      </div>',

  );

  $args = array(
    'id_form'           => 'commentform',
    'class_form'        => 'comment-form',
    'id_submit'         => 'submit',
    'class_submit'      => 'submit',
    'name_submit'       => 'submit',
    'title_reply'       => __( 'Leave a Reply', 'poetic' ),
    'title_reply_to'    => __( 'Leave a Reply to %s', 'poetic' ),
    'cancel_reply_link' => __( 'Cancel Reply', 'poetic' ),
    'label_submit'      => __( 'Post Comment', 'poetic' ),
    'format'            => 'xhtml',

    'comment_field' => 
      '<div class="form-group fc-container">
        <label for="comment" class="sr-only">' . __( 'Message', 'poetic' ) . '</label>
        <textarea name="comment" class="form-field" id="comment" rows="8" cols="45" placeholder="' . __( 'Write your message here. ', 'poetic' ) . '" aria-required="true"></textarea>
      </div>',

    'fields' => apply_filters( 'comment_form_default_fields', $fields ),
  );

  comment_form( $args );
?>


<?php if ( false && 'open' == $post->comment_status ): ?>
  <div id="respond" class="<?php echo ( ! have_comments() ) ? 'no-comments' : ''; ?>">
    <div class="poetic-container-fluid">
      <h2>Share your thoughts</h2>
      <p class="cancel-comment-reply">
        <?php cancel_comment_reply_link(); ?>
      </p>

      <?php if ( get_option( 'comment_registration' ) && !$user_ID ): ?>
        <p>You must be <a href="<?php echo get_option( 'siteurl' ); ?>/wp-login.php?redirect_to=<?php echo urlencode( get_permalink() ); ?>">logged in</a> to post a comment.</p>
      <?php else: ?>
        <form action="<?php echo get_option( 'siteurl' ); ?>/wp-comments-post.php" method="post" id="commentform">
          <?php if ( $user_ID ): ?>
            <p class="loggedin">Logged in as <a href="<?php echo get_option( 'siteurl' ); ?>/wp-admin/profile.php"><?php echo $user_identity; ?></a>. <a href="<?php echo wp_logout_url(); ?>" title="Log out of this account">Logout &raquo;</a></p>
          <?php else: ?>

          <div class="row">
            <div class="form-group fc-container">
              <label for="author" class="sr-only">Name <?php if ( $req ) echo " <span class=\"required\">*</span>"; ?></label>
              <input type="text" class="form-field" name="author" id="author" value="<?php echo $comment_author; ?>" placeholder="Name">
            </div>
            <div class="form-group fc-container">
              <label for="email" class="sr-only">Email <?php if ( $req ) echo " <span class=\"required\">*</span>"; ?></label>
              <input type="text" class="form-field" name="email" id="email" value="<?php echo $comment_author_email; ?>" placeholder="Email">
            </div>
            <div class="form-group fc-container">
              <label for="url" class="sr-only">Website</label>
              <input type="text" class="form-field" name="url" id="url" value="<?php echo $comment_author_url; ?>" placeholder="Website">
            </div>
          </div>
      <?php endif; ?>
          <div class="form-group">
            <label for="comment" class="sr-only">Message</label>
            <textarea name="comment" class="form-field" id="comment" rows="10" cols="50" placeholder="Write your message here. "></textarea>
          </div>
          <div class="form-group form-submit">
            <!-- <input type="submit" name="submit" id="submit" value="Submit Comment" class="button button-primary" /> -->
            <button type="submit" class="poetic-btn poetic-btn-primary">Submit</button>
            <input type="hidden" name="comment_post_ID" value="<?php echo $id; ?>" />
            <?php comment_id_fields(); ?>
            <?php do_action( 'comment_form', $post->ID ); ?>
          </div>
      </form>
    <?php endif; ?>
    </div>
  </div>
<?php endif; ?>