<?php 

/**
 * Helper Functions
 */

function poetic_style_font_size ( $size ) {
  $output = '';

  if ( $size != '' ) {
    $size    = str_replace( 'px', '', $size );
    $output .= 'font-size: ' . $size . 'px;';
    $output .= 'font-size: ' . $size / 10 . 'rem;';
  }

  return $output;
}

function poetic_style_color ( $color ) {
  $output = '';

  if ( $color ) {
    $output .= 'color: ' . $color . ';';
  }

  return $output;
}

function poetic_style_bg_color ( $color ) {
  $output = '';

  if ( $color ) {
    $output .= 'background-color: ' . $color . ';';
  }

  return $output;
}

function poetic_line_height ( $height ) {
  $output = '';
  
  if ( $height ) {
    $output .= 'line-height: ' . $height . ';';
  }

  return $output;
}

/**
 * Variables
 */

// 
// Site Colors
// 

$site_color                = poetic_get_theme_mod( 'site_color' );
$site_color_hover          = poetic_get_theme_mod( 'site_color_hover' );
$site_background_color     = poetic_get_theme_mod( 'site_bg_color' );

// 
// Font Sizes
// 

$type_font_size_body       = poetic_get_theme_mod( 'type_font_size_body' );
$type_font_size_h1         = poetic_get_theme_mod( 'type_font_size_h1' );
$type_font_size_h2         = poetic_get_theme_mod( 'type_font_size_h2' );
$type_font_size_h3         = poetic_get_theme_mod( 'type_font_size_h3' );
$type_font_size_h4         = poetic_get_theme_mod( 'type_font_size_h4' );
$type_font_size_h5         = poetic_get_theme_mod( 'type_font_size_h5' );
$type_font_size_h6         = poetic_get_theme_mod( 'type_font_size_h6' );
$type_font_size_logo       = poetic_get_theme_mod( 'type_font_size_logo' );

// 
// Colors
// 

$type_color_body           = poetic_get_theme_mod( 'type_color_body' );
$type_color_headings       = poetic_get_theme_mod( 'type_color_headings' );
$type_color_logo           = poetic_get_theme_mod( 'type_color_logo' );

// 
// Line Heights
// 

$type_line_height_body     = poetic_get_theme_mod( 'type_line_height_body' );
$type_line_height_headings = poetic_get_theme_mod( 'type_line_height_headings' );

// 
// Header
// 

$header_bg_color           = poetic_get_theme_mod( 'header_bg_color' );
$header_bg_color_opacity   = poetic_get_theme_mod( 'header_bg_color_opacity' );
$header_logo_width         = poetic_get_theme_mod( 'header_logo_width' );

/**
 * Output: Typography
 */

?>

/**
 * Typography
 */

/** Body **/

body {
  <?php echo poetic_style_font_size( $type_font_size_body ); ?>
  line-height: <?php echo $type_line_height_body; ?>;
  color: <?php echo $type_color_body; ?>;
  <?php echo poetic_style_bg_color( $site_background_color ); ?>
}

/** Headings **/

h1, h2, h3, h4, h5, h6 {
  color: <?php echo $type_color_headings; ?>;
  line-height: <?php echo $type_line_height_headings; ?>;
}

h1 { <?php echo poetic_style_font_size( $type_font_size_h1 ); ?> }
h2 { <?php echo poetic_style_font_size( $type_font_size_h2 ); ?> }
h3 { <?php echo poetic_style_font_size( $type_font_size_h3 ); ?> }
h4 { <?php echo poetic_style_font_size( $type_font_size_h4 ); ?> }
h5 { <?php echo poetic_style_font_size( $type_font_size_h5 ); ?> }
h6 { <?php echo poetic_style_font_size( $type_font_size_h6 ); ?> }


/** Logo Font Color **/

.poetic-logo {
  <?php echo poetic_style_font_size( $type_font_size_logo ); ?>
  <?php echo poetic_style_color( $type_color_logo ); ?>
}

.poetic-logo:hover {
  <?php echo poetic_style_color( $type_color_logo ); ?>
}

<?php if ( $header_logo_width != '' ): ?>
.poetic-logo img {
  max-width: <?php echo str_replace( 'px', '', $header_logo_width ); ?>px;
}
<?php endif; ?>

<?php 
// ---------------------------------
// Site Primary Colors 
// ---------------------------------
?>

/**
 * Primary Colors
 */

/* .poetic-header, */
.poetic-header:before,
.h-entry .entry-title:before,
.h-entry .entry-title:after,
.btn, button, input[type="button"], input[type="reset"], input[type="submit"],
.poetic-recent-posts .poetic-recent-post > a:hover .poetic-recent-post-img:before,
.poetic-nav > li > a,
button, input[type="button"], input[type="reset"], input[type="submit"],
hr.primary,
#breadcrumbs ul,
.wp-pagenavi .current,
.wp-pagenavi span.current {
  <?php echo poetic_style_bg_color( $site_color ); ?>
}

.wp-pagenavi .current,
.wp-pagenavi span.current {
  border-color: <?php echo $site_color; ?>;
}

a,
.poetic-topbar .poetic-nav > li.current-menu-item > a, 
.poetic-topbar .poetic-nav > li:hover > a,
.h-entry .entry-footer a:hover,
.widget a:hover,
.nav-btn,
.widget ul li a:hover {
  <?php echo poetic_style_color( $site_color ); ?>
}

a:hover, .btn:hover, button:hover, input[type="button"]:hover, input[type="reset"]:hover, input[type="submit"]:hover {
  <?php echo poetic_style_color( $site_color_hover ); ?>
}

/** Header **/
.poetic-header:before {
  <?php echo poetic_style_bg_color( $header_bg_color ); ?>
  opacity: <?php echo $header_bg_color_opacity; ?>;
  filter: alpha(opacity=<?php echo $header_bg_color_opacity; ?> * 100); //IE8
}

<?php 
// ---------------------------------
// Site Miscellaneous
// ---------------------------------
?>

<?php if ( $site_background_color != '' ) : ?>
.h-entry .entry-title:before {
  border-bottom-color: <?php echo $site_background_color; ?>;
}
<?php endif; ?>