<?php

/**
 * Allow Shortcodes in Widgets
 */

add_filter('widget_text', 'do_shortcode');

/**
 * Content Width
 */

if ( ! isset($content_width) ) $content_width = 500;

/**
 * Scripts & Styles Include
 */

if ( ! function_exists('include_custom_scripts_styles') ) :
  function include_custom_scripts_styles() {
    wp_enqueue_style('slick', get_template_directory_uri() . '/css/vendor/slick.css');
  }
  add_action('wp_enqueue_scripts', 'include_custom_scripts_styles');
endif;

/**
 * Sidebars
 */

function poetic_register_sideabrs() {
  if ( function_exists('register_sidebar') ) {
    register_sidebar(array(
      'name'          => 'Sidebar Before Content',
      'id'            => 'sidebar-before',
      'before_widget' => '<div id="%1$s" class="widget %2$s">',
      'after_widget'  => '</div>',
      'before_title'  => '<h3 class="widget-title">',
      'after_title'   => '</h3>',
    ));

    register_sidebar(array(
      'name'          => 'Sidebar After Content',
      'id'            => 'sidebar-after',
      'before_widget' => '<div id="%1$s" class="widget %2$s">',
      'after_widget'  => '</div>',
      'before_title'  => '<h3 class="widget-title">',
      'after_title'   => '</h3>',
    ));
  }
}

add_action( 'widgets_init', 'poetic_register_sideabrs' );

/**
 * Headline
 */

// function custom_headline() {
//   return ( get_field('_heading') && function_exists('get_field') ) ? get_field('_heading') : the_title();
// }

/**
 * Custom Excerpt Length
 */

function custom_excerpt_length( $length ) {
  return 30;
}
add_filter( 'excerpt_length', 'custom_excerpt_length', 999 );

/**
 * Remove Excerpt [...]
 */

function new_excerpt_more( $more ) {
  return '';
}
add_filter('excerpt_more', 'new_excerpt_more');

/**
 * Post Navigation
 */

if ( ! function_exists('post_navigation')) :
  function post_navigation() {
    $prev_post = get_adjacent_post( false, '', false );
    $next_post = get_adjacent_post( false, '', true );
    ?>
    <div class="post-navigation">
      <?php if ( $prev_post ) : ?>
        <a href="<?php echo get_permalink( $prev_post ); ?>" title="Previous Post" class="prev">Previous Post</a>
      <?php endif; if ( $next_post ) : ?>
        <a href="<?php echo get_permalink( $next_post ); ?>" title="Next Post" class="next">Next Post</a>
      <?php endif; ?>
    </div>
  <?php }
endif;

/**
 * Add Category Nick Names in Body & Post Class
 */

function category_id_class( $classes ) {
  global $post;
  foreach ( ( get_the_category( $post->ID ) ) as $category ) {
    $classes[] = $category->category_nicename;
  }
  return $classes;
}
add_filter( 'post_class', 'category_id_class' );
add_filter( 'body_class', 'category_id_class' );

// Remove 'hentry' and add 'h-entry' to Post Class
// ===============================================

function update_mf_post_class( $classes ) {
  global $post;
  $classes = array_diff( $classes, array("hentry") );
  $classes[] = 'h-entry';
  return $classes;
}
add_filter( 'post_class', 'update_mf_post_class' );

/**
 * Archive Box
 */

if ( ! function_exists( 'poetic_welcome_box' ) ) :
  function poetic_welcome_box() {

    $is_home     = is_home();
    $is_category = is_category();
    $is_tag      = is_tag();
    $is_month    = is_month();
    $is_year     = is_year();
    $is_author   = is_author();
    $is_search   = is_search();
    $is_paged    = isset($_GET['paged']) && !empty($_GET['paged']);

    $title    = ( $is_home ) ? '<h3>' : '<h1>';
    $desc     = '';
    $homepage = poetic_get_theme_mod( 'welcome_box_homepage' );
    $archive  = poetic_get_theme_mod( 'welcome_box_archive' );

    if ( $is_home ) {
      $title .= ( $v = poetic_get_theme_mod( 'welcome_box_homepage_title' ) ) ? $v : 'Welcome to ' . get_bloginfo( 'name' );
      $desc  = poetic_get_theme_mod( 'welcome_box_homepage_desc' );
    } elseif ( $is_category ) {
      $cat_title = single_cat_title( '', false );
      $title     .= 'Category Archive: ' . $cat_title;
      $desc      = category_description();
    } elseif ( $is_tag ) {
      $title .= 'Tag Archive: ' . single_tag_title( '', false );
    } elseif ( $is_month ) { 
      $title .= 'Month Archive: ' . get_the_time( 'F jS, Y' );
    } elseif ( $is_year ) { 
      $title .= 'Year Archive: ' . get_the_time( 'F, Y' );
    } elseif ( $is_author ) {
      $title .= 'Posts By Author: ' . get_the_author();
    } elseif ( $is_paged ) {
      $title .= 'Blog Archives';
    } elseif ( $is_search ) {
      $title .= 'Search Results';
      $s = $_GET["s"];
      if ( have_posts() ) {
        $desc = 'Your search topic <strong>' . esc_html( $s ) . '</strong>  returned the following articles:';
      } else {
        $desc = 'Sorry, but your search term <strong>' . esc_html( $s ) . '</strong> returned <strong>0</strong> results.';
      }
    }

    $title .= ( $is_home ) ? '</h3>' : '</h1>';

    if ( $title == '' && $desc == '') {
      return;
    }

    if ( is_front_page() && $homepage == 0 ) {
      return;
    }

    if ( is_archive() && $archive == 0 ) {
      return;
    }

    if ( $desc ) {
      $desc = '<p>' . $desc . '</p>';
    }

    $output = '<div class="poetic-welcome-box">' . $title . $desc . '</div>';

    echo $output;
  }
endif;

/**
 * Custom Comments Template
 */

function custom_comments_template($comment, $args, $depth) {
  $GLOBALS['comment'] = $comment;
  extract($args, EXTR_SKIP);

  if ( 'div' == $args['style'] ) {
    $tag = 'div';
    $add_below = 'comment';
  } else {
    $tag = 'li';
    $add_below = 'div-comment';
  }
?>
  <<?php echo $tag ?> <?php comment_class( empty( $args['has_children'] ) ? '' : 'parent' ) ?> id="comment-<?php comment_ID() ?>">
  <?php if ( 'div' != $args['style'] ) : ?>
  <div id="div-comment-<?php comment_ID() ?>" class="comment-body">
  <?php endif; ?>
    <div class="thumb"><?php if ( $args['avatar_size'] != 0 ) echo get_avatar( $comment, 60 ); ?></div>
    
    <div class="comment-content">
      <div class="comment-meta commentmetadata">
        <?php 
          printf( __( '<span class="comment-author vcard"><cite class="fn">%1$s</cite></span> <span class="says">on</span> <a href="%2$s" class="comment-time">%3$s</a>' ), 
            get_comment_author_link(), 
            htmlspecialchars( get_comment_link( $comment->comment_ID ) ),
            get_comment_date()
          ); 
          edit_comment_link( __( '(Edit)', 'poetic' ), '  ', '' );
        ?>
      </div>

      <?php if ( $comment->comment_approved == '0' ) : ?>
        <em class="comment-awaiting-moderation"><?php _e( 'Your comment is awaiting moderation.', 'poetic' ); ?></em>
        <br />
      <?php endif; ?>
      
      <?php comment_text(); ?>

      <div class="reply">
      <?php comment_reply_link( array_merge( $args, array( 'add_below' => $add_below, 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
      </div>
      <?php if ( 'div' != $args['style'] ) : ?>
      </div>
      <?php endif; ?>
    </div>

<?php
}


if(! function_exists('custom_avatar')){
  function custom_avatar($avatar_defaults){
    $new_default_icon = get_template_directory_uri() . '/images/avatar.png';
    $avatar_defaults[$new_default_icon] = 'Custom Comment Avatar';
    return $avatar_defaults;
  }
  add_filter('avatar_defaults','custom_avatar');
}

/**
 * Default Pagination if WP_Pagenavi is not Available
 */

function poetic_pagination() {
  if ( function_exists('wp_pagenavi') ) {
    wp_pagenavi(); 
  } else {
    $prev_posts = get_previous_posts_link( '< Older Entries' );
    $next_posts = get_next_posts_link( 'Newer Entries >' );
    if ( $prev_posts || $next_posts ) {
      $output = '<div class="poetic-pagination prev-next">'
                . $prev_posts
                . $next_posts
              . '</div>';
      echo $output;
    }
  }
}

/**
 * Add Classes to Previous and Next Posts Link
 */

add_filter('previous_posts_link_attributes', 'poetic_previous_posts_class');
add_filter('next_posts_link_attributes', 'poetic_next_posts_class');

function poetic_previous_posts_class() {
  return 'class="prev"';
}

function poetic_next_posts_class() {
  return 'class="next"';
}

/**
 * Counts Post Views
 * 
 * Code Source: WPBeginner 
 * Code Source URL: http://www.wpbeginner.com/wp-tutorials/how-to-track-popular-posts-by-views-in-wordpress-without-a-plugin/
 */

function poetic_set_post_views( $postID ) {
  $count_key = 'poetic_post_views_count';
  $count     = get_post_meta( $postID, $count_key, true );

  if ( $count == '' ){
    $count = 0;
    delete_post_meta( $postID, $count_key );
    add_post_meta( $postID, $count_key, '0' );
  } else {
    $count++;
    update_post_meta( $postID, $count_key, $count );
  }
}

// To keep the count accurate, lets get rid of prefetching
remove_action( 'wp_head', 'adjacent_posts_rel_link_wp_head', 10, 0);

function poetic_get_post_views ( $postID ){
  $count_key = 'poetic_post_views_count';
  $count     = get_post_meta( $postID, $count_key, true );
  if ( $count == '' ) {
    delete_post_meta( $postID, $count_key );
    add_post_meta( $postID, $count_key, '0' );
    return '0 View';
  }
  return $count . ' Views';
}

function poetic_track_post_views ($post_id) {
  if ( !is_single() ) return;
  if ( empty ( $post_id) ) {
    global $post;
    $post_id = $post->ID;    
  }
  poetic_set_post_views($post_id);
}
add_action( 'wp_head', 'poetic_track_post_views');

/**
 * Get WP_TITLE
 */

function poetic_wp_title( $title ) {
  return $title . get_bloginfo('name');
}

add_filter( 'wp_title', 'poetic_wp_title' );
