<?php 

/**
 * Post Entry Meta
 *
 * Outputs post entry meta
 */

if ( ! function_exists( 'poetic_post_meta' ) ) :
  function poetic_post_meta() {
    
    GLOBAL $post;

    //
    // Author. Date.
    //

    if ( is_single() || $post->post_type == 'page' ) {
      $author = sprintf( '<span class="author vcard"><i class="fa fa-user"></i> <span class="fn">%s</span></span>',
        get_the_author()
      );

      $date = sprintf( '<span><i class="fa fa-clock-o"></i> <time class="entry-date" datetime="%1$s">%2$s</time></span>',
        esc_attr( get_the_date( 'c' ) ),
        esc_html( get_the_date() )
      );
    } else {
      $author = sprintf( '<span class="author vcard"><i class="fa fa-user"></i> <span class="fn"><a href="%1$s">%2$s</a></span></span>',
        get_author_posts_url(get_the_author_meta( 'ID' )),
        get_the_author()
      );

      $date = sprintf( '<span><i class="fa fa-clock-o"></i> <a href="%3$s"><time class="entry-date" datetime="%1$s">%2$s</time></a></span>',
        esc_attr( get_the_date( 'c' ) ),
        esc_html( get_the_date() ),
        esc_html( get_day_link( get_the_date('Y'), get_the_date('m'), get_the_date('d') ) )
      );
    }

    //
    // Categories.
    //

    $categories        = get_the_category();
    $separator         = ', ';
    $categories_output = '';
    foreach ( $categories as $category ) {
      $categories_output .= '<a href="'
                          . get_category_link( $category->term_id )
                          . '" title="'
                          . esc_attr( sprintf( __( "View all posts in: &ldquo;%s&rdquo;", 'poetic' ), $category->name ) )
                          . '"> '
                          . $category->name
                          . '</a>'
                          . $separator;
    }

    $categories_list = sprintf( '<span><i class="fa fa-tags"></i> %s</span>', trim( $categories_output, $separator ) );

    //
    // Comments link.
    //

    if ( comments_open() && $post->post_type != 'page' ) {

      $title  = get_the_title();
      $link   = get_comments_link();
      $number = get_comments_number();

      if ( $number == 0 ) { $text = 'Leave a Comment'; } 
      else if ( $number == 1 ) { $text = $number . ' Comment'; } 
      else { $text = $number . ' Comments'; }

      $comments = sprintf( '<span><i class="fa fa-comments"></i> <a href="%1$s" title="%2$s" class="meta-comments">%3$s</a></span>',
        esc_url( $link ),
        esc_attr( sprintf( 'Leave a comment on: &ldquo;%s&rdquo;', $title ) ),
        $text
      );

    } else {
      $comments = '';
    }

    printf( '<p class="meta">%1$s%2$s%3$s%4$s</p>',
      $author,
      $date,
      $categories_list,
      $comments
    );
  }
endif;